@@ -1,5 +1,5 @@
 /* Target definitions for GNU compiler for PowerPC running System V.4
-   Copyright (C) 1995, 1996, 1997, 1998, 1999 Free Software Foundation, Inc.
+   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
    Contributed by Cygnus Support.
 
 This file is part of GNU CC.
@@ -1338,12 +1338,18 @@ do {									\
 
 #ifndef CPP_OS_LINUX_SPEC
 #ifdef USE_GNULIBC_1
-#define CPP_OS_LINUX_SPEC "-D__unix__ -D__linux__ \
-%{!undef:%{!ansi:%{!std=*:-Dunix -Dlinux}%{std=gnu*:-Dunix -Dlinux}}} \
+#define CPP_OS_LINUX_SPEC "-D__unix__ -D__linux__		\
+%{!undef:							\
+  %{!ansi:							\
+    %{!std=*:-Dunix -D__unix -Dlinux -D__linux}			\
+    %{std=gnu*:-Dunix -D__unix -Dlinux -D__linux}}}		\
 -Asystem(unix) -Asystem(posix)"
 #else
-#define CPP_OS_LINUX_SPEC "-D__unix__ -D__linux__ \
-%{!undef:%{!ansi:%{!std=*:-Dunix -Dlinux}%{std=gnu*:-Dunix -Dlinux}}} \
+#define CPP_OS_LINUX_SPEC "-D__unix__ -D__linux__		\
+%{!undef:							\
+  %{!ansi:							\
+    %{!std=*:-Dunix -D__unix -Dlinux -D__linux}			\
+    %{std=gnu*:-Dunix -D__unix -Dlinux -D__linux}}}		\
 -Asystem(unix) -Asystem(posix) %{pthread:-D_REENTRANT}"
 #endif
 #endif
